🚀 go-pugleaf

RetroBBS NetNews Server

Inspired by RockSolid Light RIP Retro Guy

Article View: alt.os.linux.suse
Article #427

Re: gcc 3.2 makes slower code

#427
From: Moritz Franosch
Date: Fri, 29 Nov 2002 15:19
53 lines
3059 bytes
"Jeffrey Cunningham" <jeffrey@cunningham.net> writes:

> I've re-run my simulation with the following flags, as suggested by Moritz
> Franosch:
> 
> -O3 offast-math -funroll-loops -march=i686
> 
> It made it slightly faster. So here's the summary:
> 
> 2.95 w/-O3: 0.17 minutes per iteration
> 3.2 w/-O3:  0.28 minutes per iteration

> 3.2 w/-MF:  0.24 minutes per iteration

Still much too slow. If gcc 3.2 performs 20% slower (even 40% in this
case) for a certain piece of code than gcc 2.95, I would consider this
as a performance bug. Gcc people should be interested in it, even more
so if you can identify the piece of code so that it is reasonably
short (and gcc people can look at the assembler output). If you don't
get your code much faster with the options below, I'd report it as a
performance bug.

> (MF=Moritz Franosch's flags). 
> 
> Better, but no cigar.I haven't tried either the -Ox or the
> -fstrict-aliasing yet. Later...

With -Ox I've meant -O, -O2 or -O3. Inline assembler math functions
are only enabled when using -ffast-math plus one of the -Ox.

I've just seen that -fstrict-aliasing ist turned on by -O2 in gcc 3.2
anyway (look at the info file).

You could also try these
-fomit-frame-pointer
-finline-functions
-fno-math-errno
-funsafe-math-optimizations
-fno-trapping-math
-fno-exceptions 

Some of them change program behavior, so you should check your results
and read the info file if you want to use these options in your
production code.


Moritz


-- 
Dipl.-Phys. Moritz Franosch
http://Franosch.org
Technical Details
Message-ID: <m3r8d4wgif.fsf@gateway.askos>
Path: arc1-ca.pugleaf.net!archiver1.google.com!news1.google.com!newsfeed.stanford.edu!news.tele.dk!news.tele.dk!small.news.tele.dk!fu-berlin.de!uni-berlin.de!pd9e94352.dip0.t-ipconnect.DE!not-for-mail
References: <pan.2002.11.24.02.51.19.422739@cunningham.net> <arqit4$4n6$1@condor.gjs.xs4all.nl> <pan.2002.11.25.05.30.25.633705@cunningham.net> <uu3e5l1f71fs38@corp.supernews.com> <pan.2002.11.25.19.02.02.459662@cunningham.net> <KhvE9.114918$WL3.49933@rwcrnsc54> <m3bs4cz3gl.fsf@gateway.askos> <fTNE9.124523$%m4.59288@rwcrnsc52.ops.asp.att.net> <m3u1i4xfq5.fsf@gateway.askos> <9NSE9.126578$%m4.59621@rwcrnsc52.ops.asp.att.net> <pan.2002.11.28.08.49.33.24531@cunningham.net> <pan.2002.11.29.00.52.37.104681@cunningham.net>

Show Full Headers
Complete Article Headers
X-Google-Language: ENGLISH,ASCII-7-bit
X-Google-Thread: 1041dd,6b8a900e383d587f
X-Google-Attributes: gid1041dd,public
X-Google-Thread: f65d0,cf9dda410d7d1076
X-Google-Attributes: gidf65d0,public
X-Google-ArrivalTime: 2002-11-29 07:19:07 PST
Path: arc1-ca.pugleaf.net!archiver1.google.com!news1.google.com!newsfeed.stanford.edu!news.tele.dk!news.tele.dk!small.news.tele.dk!fu-berlin.de!uni-berlin.de!pd9e94352.dip0.t-ipconnect.DE!not-for-mail
From: Moritz Franosch <mail@Franosch.org>
Newsgroups: alt.os.linux.suse,gnu.gcc
Subject: Re: gcc 3.2 makes slower code
Date: 29 Nov 2002 16:19:04 +0100
Lines: 53
Sender: mf@gateway.askos
Message-ID: <m3r8d4wgif.fsf@gateway.askos>
References: <pan.2002.11.24.02.51.19.422739@cunningham.net> <arqit4$4n6$1@condor.gjs.xs4all.nl> <pan.2002.11.25.05.30.25.633705@cunningham.net> <uu3e5l1f71fs38@corp.supernews.com> <pan.2002.11.25.19.02.02.459662@cunningham.net> <KhvE9.114918$WL3.49933@rwcrnsc54> <m3bs4cz3gl.fsf@gateway.askos> <fTNE9.124523$%m4.59288@rwcrnsc52.ops.asp.att.net> <m3u1i4xfq5.fsf@gateway.askos> <9NSE9.126578$%m4.59621@rwcrnsc52.ops.asp.att.net> <pan.2002.11.28.08.49.33.24531@cunningham.net> <pan.2002.11.29.00.52.37.104681@cunningham.net>
NNTP-Posting-Host: pd9e94352.dip0.t-ipconnect.de (217.233.67.82)
Mime-Version: 1.0
Content-Type: text/plain; charset=us-ascii
X-Trace: fu-berlin.de 1038583146 25610419 217.233.67.82 (16 [163233])
User-Agent: Gnus/5.0808 (Gnus v5.8.8) XEmacs/21.4 (Artificial Intelligence)